@@ -57,7 +57,7 @@ static void     gail_set_focus_widget (GtkWidget *focus_widget,
 static void     gail_set_focus_object (AtkObject *focus_obj,
                                        AtkObject *obj);
 
-static GtkWidget* focus_widget = NULL;
+GtkWidget* focus_widget = NULL;
 static GtkWidget* next_focus_widget = NULL;
 static gboolean was_deselect = FALSE;
 static GtkWidget* subsequent_focus_widget = NULL;
@@ -153,7 +153,12 @@ gail_get_accessible_for_widget (GtkWidget *widget,
 
       if (canvas->focused_item)
         {
+          AtkObject *tmp;
+
           obj = atk_gobject_accessible_for_object (G_OBJECT (canvas->focused_item));
+          tmp = g_object_get_qdata (G_OBJECT (obj), quark_focus_object);
+          if (tmp != NULL)
+            obj = tmp;
         }
     }
   else if (GTK_IS_TOGGLE_BUTTON (widget))
