@@ -28,7 +28,7 @@ static void	  gail_label_real_initialize	   (AtkObject 	      *obj,
                                                     gpointer	      data);
 static void	  gail_label_real_notify_gtk	   (GObject	      *obj,
                                                     GParamSpec	      *pspec);
-static gint       gail_label_map_gtk               (GtkWidget         *widget,
+static void       gail_label_map_gtk               (GtkWidget         *widget,
                                                     gpointer          data);
 static void       gail_label_init_text_util        (GailLabel         *gail_label,
                                                     GtkWidget         *widget);
@@ -163,7 +163,6 @@ static void
 gail_label_real_initialize (AtkObject *obj,
                             gpointer  data)
 {
-  GtkLabel  *label;
   GtkWidget  *widget;
   GailLabel *gail_label;
 
@@ -208,7 +207,7 @@ gail_label_real_initialize (AtkObject *obj,
     obj->role = ATK_ROLE_LABEL;
 }
 
-static gint
+static void
 gail_label_map_gtk (GtkWidget *widget,
                     gpointer data)
 {
@@ -330,6 +329,7 @@ gail_label_real_notify_gtk (GObject           *obj,
       if (!gail_label->has_top_level)
         {
           temp_obj = atk_obj;
+          top_level = NULL;
           while (temp_obj)
             {
               top_level = temp_obj;
@@ -498,7 +498,7 @@ gail_label_ref_relation_set (AtkObject *obj)
                           list = gtk_container_get_children (GTK_CONTAINER (temp_widget));
                           if (GTK_IS_COMBO (list->data))
                             {
-                              mnemonic_widget = GTK_COMBO (list->data);
+                              mnemonic_widget = GTK_WIDGET (list->data);
                             }
                         }
                     }
@@ -521,10 +521,13 @@ gail_label_ref_relation_set (AtkObject *obj)
 static G_CONST_RETURN gchar*
 gail_label_get_name (AtkObject *accessible)
 {
+  G_CONST_RETURN gchar *name;
+
   g_return_val_if_fail (GAIL_IS_LABEL (accessible), NULL);
 
-  if (accessible->name != NULL)
-    return accessible->name;
+  name = ATK_OBJECT_CLASS (parent_class)->get_name (accessible);
+  if (name != NULL)
+    return name;
   else
     {
       /*
