@@ -50,7 +50,6 @@ static gboolean         gail_toplevel_show_event_watcher (GSignalInvocationHint
 
 static void      _gail_toplevel_remove_child            (GailToplevel           *toplevel,
                                                         GtkWindow               *window);
-static gboolean  is_tooltip_window                      (GtkWidget              *widget);
 static gboolean  is_attached_menu_window                (GtkWidget              *widget);
 static gboolean  is_combo_window                        (GtkWidget              *widget);
 
@@ -133,8 +132,7 @@ gail_toplevel_object_init (GailToplevel *toplevel)
           !GTK_WIDGET_VISIBLE (widget) ||
           is_attached_menu_window (widget) ||
           GTK_WIDGET (window)->parent ||
-          GTK_IS_PLUG (window) ||
-          is_tooltip_window (widget))
+          GTK_IS_PLUG (window))
         {
           GList *temp_l  = l->next;
 
@@ -238,8 +236,7 @@ gail_toplevel_show_event_watcher (GSignalInvocationHint *ihint,
   if (widget->parent || 
       is_attached_menu_window (widget) ||
       is_combo_window (widget) ||
-      GTK_IS_PLUG (widget) || 
-      is_tooltip_window (widget))
+      GTK_IS_PLUG (widget))
     return TRUE;
 
   /* Add the window to the list & emit the signal */
@@ -326,18 +323,6 @@ _gail_toplevel_remove_child (GailToplevel *toplevel,
     }
 }
 
-static gboolean
-is_tooltip_window (GtkWidget *widget)
-{
-  const gchar *name;
-
-  name = gtk_widget_get_name (widget);
-  if (name && strcmp (name, "gtk-tooltips") == 0)
-    return TRUE;
-  else
-    return FALSE;
-}
-
 static gboolean
 is_attached_menu_window (GtkWidget *widget)
 {
