@@ -49,6 +49,10 @@ struct _GailTreeView
   GArray*	row_data;
   GList*        cell_data;
   GtkTreeModel  *tree_model;
+  AtkObject     *focus_cell;
+  GtkAdjustment *old_hadj;
+  GtkAdjustment *old_vadj;
+  guint         idle_expand_id;
 };
 
 GType gail_tree_view_get_type (void);
